@@ -149,7 +149,7 @@ zenity_scale_dialog_response (GtkWidget *widget, int response, gpointer data)
       break;
 
     default:
-      if (response < g_strv_length(zen_data->extra_label))
+      if (zen_data->extra_label && response < g_strv_length(zen_data->extra_label))
         printf("%s\n",zen_data->extra_label[response]);
       zen_data->exit_code = zenity_util_return_exit_code (ZENITY_ESC);
       break;
